<?php

/**
 * Photo Spot
 *
 * @version 1.0
 * @author Creative Pulse
 * @copyright Creative Pulse 2009
 * @license GNU/GPLv2
 * @link http://www.creativepulse.eu
 */


class PhotoSpotDatasourceContentArticlesDisplay extends PhotoSpotDatasourceDisplay {

	function analyze($content) {
		$item = null;

		if (preg_match('~<\s*img.*?>~is', $content, $m)) {
			preg_match_all('~(\w*)\s*=\s*"([^"]*)"~s', $m[0], $m2);

			$attrs = array();
			for ($i = 0, $len = count($m2[0]); $i < $len; $i++)
				$attrs[strtolower($m2[1][$i])] = trim($m2[2][$i]);

			if (isset($attrs['src'])) {
				$item = new PhotoSpotDisplayItem();

				$item->link = $this->current_link;

				$item->img_url = $attrs['src'];

				$item->ext = strrchr($item->img_url, '.');
				if (!empty($item->ext))
					$item->ext = strtolower(substr($item->ext, 1));

				if (isset($attrs['title']))
					$item->title = $attrs['title'];
				else if (isset($attrs['alt']))
					$item->title = $attrs['alt'];

				if (isset($attrs['width']))
					$item->img_width = $attrs['width'];

				if (isset($attrs['height']))
					$item->img_height = $attrs['height'];
			}
		}

		return $item;
	}

	function init($viewer) {
		require_once(JPATH_SITE . '/components/com_content/helpers/route.php');

		$db =& JFactory::getDBO();

		$user =& JFactory::getUser();
		$aid = $user->get('aid', 0);

		$contentConfig =& JComponentHelper::getParams('com_content');
		$noauth = !$contentConfig->get('show_noauth');
		$date =& JFactory::getDate();
		$now = $date->toMySQL();

		$nullDate = $db->getNullDate();

		preg_match_all('/[0-9]+/', $this->params->get('articles', ''), $article_ids);
		preg_match_all('/[0-9]+/', $this->params->get('categories', ''), $cat_ids);
		preg_match_all('/[0-9]+/', $this->params->get('sections', ''), $sec_ids);

		$query_base =
'FROM #__content AS a
INNER JOIN #__categories AS cc ON cc.id = a.catid
INNER JOIN #__sections AS s ON s.id = a.sectionid
WHERE a.state = 1
' . (empty($article_ids[0]) ? '' : 'AND a.id IN (' . implode(',', $article_ids[0]) . ')') . '
' . (empty($cat_ids[0]) ? '' : 'AND a.catid IN (' . implode(',', $cat_ids[0]) . ')') . '
' . (empty($sec_ids[0]) ? '' : 'AND a.sectionid IN (' . implode(',', $sec_ids[0]) . ')') . '
' . ($noauth ? ' AND a.access <= ' . (int) $aid . ' AND cc.access <= ' . (int) $aid . ' AND s.access <= ' . (int) $aid : '') . '
AND (a.publish_up = ' . $db->Quote($nullDate) . ' OR a.publish_up <= ' . $db->Quote($now) . ')
AND (a.publish_down = ' . $db->Quote($nullDate) . ' OR a.publish_down >= ' . $db->Quote($now) . ')
AND cc.section = s.id
AND cc.published = 1
AND s.published = 1';

		$db->setQuery('SELECT COUNT(*) ' . $query_base);
		$this->items_count = (int) $db->loadResult();

		$order_methods = array(
			'default' => 'a.ordering',
			'title' => 'a.title',
			'cdate_desc' => 'a.created DESC',
			'cdate_asc' => 'a.created',
			'mdate_desc' => 'a.modified DESC',
			'mdate_asc' => 'a.modified',
			'random' => 'RAND()',
		);
		$order = $this->params->get('order', '');

		$query =
'SELECT a.*,
CASE WHEN CHAR_LENGTH(a.alias) THEN CONCAT_WS(":", a.id, a.alias) ELSE a.id END as slug,
CASE WHEN CHAR_LENGTH(cc.alias) THEN CONCAT_WS(":", cc.id, cc.alias) ELSE cc.id END as catslug
' . $query_base . '
ORDER BY ' . (isset($order_methods[$order]) ? $order_methods[$order] : $order_methods['default']);

		$db->setQuery($query, $viewer->limitstart, $viewer->limit);
		$records = $db->loadObjectList();

		if (is_array($records)) {
			foreach ($records as $rec) {
				$this->current_link = JRoute::_(ContentHelperRoute::getArticleRoute($rec->slug, $rec->catslug, $rec->sectionid));

				$item = $this->analyze($rec->introtext);

				if ($item === null)
					$item = $this->analyze($rec->fulltext);

				if ($item === null)
					$item = new PhotoSpotDisplayItem();

				$this->items[] = $item;
			}
		}

		return '';
	}

}

$engine = new PhotoSpotDatasourceContentArticlesDisplay();

?>