<?php

/**
 * Photo Spot
 *
 * @version 1.0
 * @author Creative Pulse
 * @copyright Creative Pulse 2009
 * @license GNU/GPLv2
 * @link http://www.creativepulse.eu
 */


class PhotoSpotDatasourceDirectoryAdmin extends PhotoSpotDatasourceAdmin {

	function setup() {
		$this->data_set('img_dir', 'images/stories');
		$this->save();
	}

	function edit() {
		$load_data = true;

		$warnings = array();

		if ($this->get('hfrm_datasource_edit', '') != '') {
			$load_data = false;
			$v_img_dir = trim($this->get('img_dir', ''));
			$v_thumb_dir = trim($this->get('thumb_dir', ''));
			$v_filter = trim($this->get('filter', ''));
			$v_order = trim($this->get('order', ''));

			if ($this->page_refreshed) {
				// ignore page refreshes
			}
			else if ($this->get('btn_cancel', '') != '') {
				// form cancelled
				$load_data = true;
			}
			else {
				// form submitted successfully

				$utils =& PhotoSpotUtils::get_instance();

				$error_msg = '';

				if ($v_img_dir == '') {
					$warnings['img_dir'] = JText::_('The image directory is not set');
				}
				else if ($v_img_dir != 'images' && substr($v_img_dir, 0, 7) != 'images/') {
					$warnings['img_dir'] = JText::_('Path is not in the images directory');
				}
				else if (strpos($v_img_dir, '..') !== false) {
					$warnings['img_dir'] = JText::_('Parent directory symbol (..) is not allowed');
				}
				else {
					$type = $utils->norm_file_paths($v_img_dir, false, $path_url, $path_abs);
					if ($type == 'notfound')
						$warnings['img_dir'] = JText::_('The image directory does not exist');
					else if ($type != 'directory')
						$warnings['img_dir'] = JText::_('The value in the image directory field is not a valid directory');
				}

				if ($error_msg == '' && $v_thumb_dir != '') {
					if ($v_thumb_dir != 'images' && substr($v_thumb_dir, 0, 7) != 'images/') {
						$warnings['thumb_dir'] = JText::_('Path is not in the images directory');
					}
					else if (strpos($v_thumb_dir, '..') !== false) {
						$warnings['thumb_dir'] = JText::_('Parent directory symbol (..) is not allowed');
					}
					else {
						$type = $utils->norm_file_paths($v_thumb_dir, false, $path_url, $path_abs);
						if ($type == 'notfound')
							$warnings['thumb_dir'] = JText::_('The thumbnail directory does not exist');
						else if ($type != 'directory')
							$warnings['thumb_dir'] = JText::_('The value in the thumbnail directory field is not a valid directory');
					}
				}

				if ($error_msg == '') {
					$this->data_set('img_dir', $v_img_dir);
					$this->data_set('thumb_dir', $v_thumb_dir);
					$this->data_set('filter', $v_filter);
					$this->data_set('order', $v_order);
					$this->save();

					global $mainframe;
					$mainframe->enqueueMessage(JText::_('Datasource updated successfully'));
				}
				else {
					JError::raiseWarning($error_msg, $error_msg);
				}
			}
		}

		if ($load_data) {
			$v_img_dir = $this->data_get('img_dir', '');
			$v_thumb_dir = $this->data_get('thumb_dir', '');
			$v_filter = $this->data_get('filter', '');
			$v_order = $this->data_get('order', '');
		}

		echo '
<form name="frm_datasource" method="post" action="index.php">
	<input type="hidden" name="hfrm_datasource_edit" value="' . microtime() . '" />
	<input type="hidden" name="option" value="' . htmlspecialchars(JRequest::getCmd('option')) . '" />
	<input type="hidden" name="task" value="' . htmlspecialchars(JRequest::getCmd('task')) . '" />
	<input type="hidden" name="id" value="' . htmlspecialchars(JRequest::getCmd('id')) . '" />

	<table cellspacing="10">
		<tr>
			<td valign="top">' . JText::_('Image Directory') . '</td>
			<td><input type="text" name="img_dir" value="' . htmlspecialchars($v_img_dir) . '" />
				&nbsp; ' . JText::_('Example') . ': images/stories
' . (empty($warnings['img_dir']) ? '' : '<br/><span class="warning">' . $warnings['img_dir'] . '</span>') . '
			</td>
		</tr>
		<tr>
			<td valign="top">' . JText::_('Thumbnail Directory') . '</td>
			<td><input type="text" name="thumb_dir" value="' . htmlspecialchars($v_thumb_dir) . '" />
' . (empty($warnings['thumb_dir']) ? '' : '<br/><span class="warning">' . $warnings['thumb_dir'] . '</span>') . '
			</td>
		</tr>
		<tr>
			<td>' . JText::_('Filter') . '</td>
			<td><input type="text" name="filter" value="' . htmlspecialchars($v_filter) . '" />
				&nbsp; ' . JText::_('Example') . ': *.jpg|*.gif|*.png|*.jpeg
			</td>
		</tr>
		<tr>
			<td>' . JText::_('Order by') . '</td>
			<td>
				<select name="order">
					<option value="default"' . ($v_order == 'default' ? ' selected="selected"' : '') . '>' . JText::_('Default order') . '</option>
					<option value="filename"' . ($v_order == 'filename' ? ' selected="selected"' : '') . '>' . JText::_('File name') . '</option>
					<option value="title"' . ($v_order == 'title' ? ' selected="selected"' : '') . '>' . JText::_('Title') . '</option>
					<option value="mdate_desc"' . ($v_order == 'mdate_desc' ? ' selected="selected"' : '') . '>' . JText::_('Date - Newer first') . '</option>
					<option value="mdate_asc"' . ($v_order == 'mdate_asc' ? ' selected="selected"' : '') . '>' . JText::_('Date - Older first') . '</option>
					<option value="random"' . ($v_order == 'random' ? ' selected="selected"' : '') . '>' . JText::_('Random') . '</option>
				</select>
			</td>
		</tr>
	</table>

	<div>
		<input type="submit" name="btn_apply" value="' . JText::_('Apply') . '" />
		<input type="submit" name="btn_cancel" value="' . JText::_('Cancel') . '" />
	</div>
</form>
';
	}

}

$engine = new PhotoSpotDatasourceDirectoryAdmin();

?>